#
# Example wscp script for creating an enterprise application 
# The script init.tcl must be loaded prior to running this script
# This script assumes that a JDBCDriver object and DataSource object exist
#
# 
# You must substitute different values for the enterprise bean to create
# (the jar, dd, bean, and attr variables)
# If desired, you can add the -WLM option to the EnterpriseBean deploy
# operation to prepare a CMP entity bean for workload management
#
# If desired, you can substitute different names for the other variables
#
# serv -- the name of an application server 
# cont -- the name of the container in the application server
# jar -- the full path name of the undeployed (EJB JAR) file 
#        containing the bean to be deployed;
#        the example JAR file used here is Card.jar
#        
#
#	   This variable is then reset to the full pathname of
#        the deployed (EJS JAR) file
# dd -- the name of the serialized deployment descriptor for the bean
# bean -- the name of the enterprise bean
# attrs -- the attribute list for setting the DeploymentDescriptor and JarFile
#          attributes; add any other additional attributes you may need, for
#          example, set the DataSource attribute for CMP entity beans
# engine -- the name of a servlet engine
# uri -- the name of a Web resource
# group -- the name of a Web application
# servlet -- the name of a servlet
# appl -- the name of an enterprise application

set serv "${NODE}ApplicationServer:Appl Server/"
# Create an ApplicationServer object
    set cmd {ApplicationServer create $serv}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

set cont "${serv}EJBContainer:Appl EJB Container/"
# Create an EJBContainer object
    set cmd {EJBContainer create $cont}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

# Deploy an EnterpriseBean object
   set jar "${WAS_HOME}${FILE_SEPARATOR}deployableEJBs${FILE_SEPARATOR}Card.jar"
   set dd "$jar/com.transarc.systest.ejs.debitCard/card1.ser"
  
    set cmd {EnterpriseBean deploy $dd -node $NODE}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

set bean "${cont}EnterpriseBean:Appl EJB/"
# Create an EnterpriseBean object
   set jar "${WAS_HOME}${FILE_SEPARATOR}deployedEJBs${FILE_SEPARATOR}DeployedCard.jar"
   set attrs "{DeploymentDescriptor com.transarc.systest.ejs.debitCard.Card@$jar}{JarFile $jar}"
    
    set cmd {EnterpriseBean create $bean -attribute $attrs}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

set engine "${serv}ServletEngine:Appl ServletEngine/"
# Create a ServletEngine object
    set cmd {ServletEngine create $engine -attribute {{Enabled true}}}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

#
# Other objects created as side-effects
#
set profile "${engine}UserProfile:User Profile Manager/"
set session "${engine}SessionManager:Session Manager/"

set uri "/VirtualHost:default_host/WebResource:/applWebResource/"
# Create a WebResource object
    set cmd {WebResource create $uri -attribute {{PathName /applWebResource}{RootURI /applWebResource}}}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


set group "${engine}WebApplication:Appl WebApplication/"
# Create a WebApplication object
    set attrs "{URIPath default_host/applWebResource}{Classpath {$WAS_HOME/hosts/default_host/default_app/servlets $WAS_HOME/servlets}}{DocRoot {$(DOCROOT)}}{Enabled true}"
    set cmd {WebApplication create $group -attribute $attrs}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


set servlet "${group}Servlet:Appl Servlet/"
# Create a Servlet object
    set cmd {Servlet create $servlet -attribute {{Code SnoopServlet}{InitParams {{param1 test-value1}}}{URIPaths {default_host/servlet/applServlet default_host/servlet/applServlet2}}{Enabled false}{UserServlet false}}}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd



set appl "/EnterpriseApplication:testAppl/"
# Create an EnterpriseApplication object
    set cmd {EnterpriseApplication create $appl}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Add an enterprise bean to the EnterpriseApplication object
    set cmd {EnterpriseApplication addRelation $appl -relationName $bean}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Add a Web application to the EnterpriseApplication object
    set cmd {EnterpriseApplication addRelation $appl -relationName $group}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Add a Web resource to the EnterpriseApplication object
    set cmd {EnterpriseApplication addRelation $appl -relationName $uri}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Start the ApplicationServer object
    set cmd {ApplicationServer start $serv}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Start the EJBContainer object
    set cmd {EJBContainer start $cont}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Start the ServletEngine object
    set cmd {ServletEngine start $engine}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Start the WebApplication object
    set cmd {WebApplication start $group}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Start the EnterpriseApplication object
    set cmd {EnterpriseApplication start $appl}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

# Optional commands for stopping and removing the application

if {0} {


# Stop the WebApplication object
    set cmd {WebApplication stop $group}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Stop the SessionManager object
    set cmd {SessionManager stop $session}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Stop the UserProfile Manager object
    set cmd {UserProfile stop $profile}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Stop the ServletEngine object
    set cmd {ServletEngine stop $engine}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Stop the ApplicationServer object
    set cmd {ApplicationServer stop $serv}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Stop the EnterpriseApplication object
    set cmd {EnterpriseApplication stop $appl}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Remove the EnterpriseBean object from the EnterpriseApplication object
    set cmd {EnterpriseApplication removeRelation $appl -relationName $bean}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Remove the WebApplication object from the EnterpriseApplication object
    set cmd {EnterpriseApplication removeRelation $appl -relationName $group}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Remove the WebResource object from the EnterpriseApplication object
    set cmd {EnterpriseApplication removeRelation $appl -relationName $uri}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Recursively remove the ApplicationServer object just created
    set cmd {ApplicationServer remove $serv -recursive}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Recursively remove the EnterpriseApplication object just created
    set cmd {EnterpriseApplication remove $appl -recursive}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

}