#
# Examples of wscp commands for administering models and clones
# The script init.tcl must be loaded before running this script

# Substitute the name of your node (in the variable base)
# If desired, substitute different values for the names of the models, and servers

set base  "/Node:doc5-pc/ApplicationServer:Default Server/"

set model1 "/Model:testModel1/"
set model2 "/Model:testModel2/"


# Create a recursive Model object from an existing instance
    set cmd {Model create $model1 -baseInstance $base -recursive -makeClone}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

# Create a nonrecursive Model object from an existing instance
    set cmd {Model create $model2 -baseInstance $base}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

set model2a "/Model:testModel2a/"
# Create a child of the previous Model object
    set cmd {Model create $model2a -modelAttrs {{CloneInterfaceClass com.ibm.ejs.sm.beans.EJBContainer}} -parentModel $model2}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Modify a Clone attribute
    set cmd {Model modify $model2 -attribute {{Attributes {Environment {testEnvVariable=just testing}}}}}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

# List Model objects and show the first Model object's Clone attributes
    set cmd {Model showAttrs [lindex [Model list] 0]}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# List clones of the first Model object
    set cmd {Model listClones $model1}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


set serv "${NODE}ApplicationServer:Model ApplicationServer/"
# Create an ApplicationServer object
    set cmd {ApplicationServer create $serv}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

set model  "${model2}Model:testModel2a/"
# Clone an existing Model object
    set cmd {Model clone $model -parentName $serv -cloneAttrs {{Name testClone}}}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


set serv2 "${NODE}ApplicationServer:Model ApplicationServer2/"
# Create another ApplicationServer object
    set cmd {ApplicationServer create $serv2}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Add another clone to an existing Model object
    set cmd {Model addClone $model2 -cloneName $serv2}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Start the first Model object
    set cmd {Model start $model1}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Stop the first Model object
    set cmd {Model start $model1}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Start the first clone of the first Model object
    set cmd {ApplicationServer start [lindex [Model listClones $model1] 0]}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd


# Stop the first clone of the first Model object
    set cmd {ApplicationServer stop [lindex [Model listClones $model1] 0]}
    if {$VERBOSE} {puts [subst "# $cmd"]}
    eval $cmd

if {0} {

# Disassociate all of the clones from all of the Model objects
    set cmd {foreach m [list $model $model1 $model2] {foreach c [Model listClones $m] {Model removeClone $m -cloneName $c}}}
    if {$VERBOSE} {puts "# $cmd"}
    eval $cmd


# Recursively remove all of the Model objects
    set cmd {foreach m [list $model $model1 $model2] {Model remove $m -recursive}}
    if {$VERBOSE} {puts "# $cmd"}
    eval $cmd


# Recursively remove the ApplicationServer objects
    set cmd {foreach s [list $serv $serv2] {ApplicationServer remove $s -recursive}}
    if {$VERBOSE} {puts "# $cmd"}
    eval $cmd
}