// 5648-C84, 5648-C83, (C) Copyright IBM Corporation, 1997, 2000
// All rights reserved. Licensed Materials Property of IBM
// Note to US Government users: Documentation related to restricted rights
// Use, duplication or disclosure is subject to restrictions set forth in GSA ADP Schedule with IBM Corp.
// This page may contain other proprietary notices and copyright information, the terms of which must be observed and followed.
//
// This program may be used, executed, copied, modified and distributed
// without royalty for the purpose of developing, using,
// marketing, or distributing.

/**
*
* Description - FeedbackQueryBean
*/
package WebSphereSamples.Feedback;
// Imports
import com.ibm.db.*;
import com.ibm.webtools.runtime.*;
import java.io.*;
import java.math.*;

// Imports for App Server V3 connection pooling
import javax.sql.DataSource;
import com.ibm.ejs.dbm.jdbcext.*;
import java.sql.*;
import java.util.*;
import com.ibm.websphere.advanced.cm.factory.*;
import javax.naming.*;

public class FeedbackQueryBean extends java.lang.Object
{
   /**
   * Instance variable for URL property
   */
   protected java.lang.String URL = null;

   /**
   * Instance variable for driver property
   */
   protected java.lang.String driver = null;

   /**
   * Variable to hold DataSource
   */
   protected DataSource ds = null;

   /**
   * Variable to hold connection
   */
   protected Connection connection = null;

   /**
   * Vector to hold name property values
   */
   protected Vector nameVector = new Vector();

   /**
   * Vector to hold email property values
   */
   protected Vector emailVector = new Vector();

   /**
   * Vector to hold subject property values
   */
   protected Vector subjectVector = new Vector();

   /**
   * Vector to hold comment property values
   */
   protected Vector commentVector = new Vector();

   /*****************************************************************************
   * Get method for the indexed NAME property
   * @param index The 0 based index of the desired value
   * @return the value of the NAME property at the specified index
   */
   public java.lang.String getNAME(int index)
   throws java.lang.ArrayIndexOutOfBoundsException
   {
      return (String)nameVector.elementAt(index);
   }

   /*****************************************************************************
   * Get method for the indexed EMAIL property
   * @param index The 0 based index of the desired value
   * @return the value of the EMAIL property at the specified index
   */
   public java.lang.String getEMAIL(int index)
   throws java.lang.ArrayIndexOutOfBoundsException
   {
      return (String)emailVector.elementAt(index);
   }

   /*****************************************************************************
   * Get method for the indexed SUBJECT property
   * @param index The 0 based index of the desired value
   * @return the value of the SUBJECT property at the specified index
   */
   public java.lang.String getSUBJECT(int index)
   throws java.lang.ArrayIndexOutOfBoundsException
   {
      return (String)subjectVector.elementAt(index);
   }

   /*****************************************************************************
   * Get method for the indexed COMMENT property
   * @param index The 0 based index of the desired value
   * @return the value of the COMMENT property at the specified index
   */
   public java.lang.String getCOMMENT(int index)
   throws java.lang.ArrayIndexOutOfBoundsException
   {
      return (String)commentVector.elementAt(index);
   }

   /*****************************************************************************
   * Get method for the URL property
   * @return the value of the URL property
   */
   public java.lang.String getURL()
   {
      return URL;
   }

   /*****************************************************************************
   * Set method for the URL property
   * @param value the new value for the URL property
   */
   public void setURL(java.lang.String value)
   {
      this.URL = value;
   }

   /*****************************************************************************
   * Get method for the driver property
   * @return the value of the driver property
   */
   public java.lang.String getDriver()
   {
      return driver;
   }

   /*****************************************************************************
   * Set method for the driver property
   * @param value the new value for the driver property
   */
   public void setDriver(java.lang.String value)
   {
      this.driver = value;
   }

   /*****************************************************************************
   * execute action method
   * @exception java.io.IOException
   * @exception java.lang.Exception
   */
   public void execute()
   throws java.io.IOException, java.lang.Exception
   {
      connection = getPooledConnection(URL, driver);
      java.sql.Statement stmt = connection.createStatement();
      ResultSet rs = stmt.executeQuery("SELECT NAME, EMAIL, SUBJECT, COMMENT FROM FEEDBACK");
      // There may be zero, one, or many rows in the table.
      while (rs.next())
      {
         nameVector.addElement(rs.getString(1));
         emailVector.addElement(rs.getString(2));
         subjectVector.addElement(rs.getString(3));
         commentVector.addElement(rs.getString(4));
      }
      nameVector.trimToSize();
      emailVector.trimToSize();
      subjectVector.trimToSize();
      commentVector.trimToSize();
      rs.close();
      stmt.close();
      connection.close();
   }

   /*****************************************************************************
   * Attempts to get a connection from a App Server V3 connection pool.
   *
   * @param URL Contains the database url for the connection
   * @param driver Contains the JDBC driver name to use for the connection
   * @return a pooled JDBC connection or null
   */
   protected Connection getPooledConnection(String URL, String driver)
   {
      Connection conn = null;

      try
      {
         // create parameter list to access naming system
         Hashtable parms = new Hashtable();
         parms.put(Context.INITIAL_CONTEXT_FACTORY, "com.ibm.ejs.ns.jndi.CNInitialContextFactory");
         // access naming system
         Context context = new InitialContext(parms);
         // get DataSource factory object from naming system
         ds = (DataSource)context.lookup("jdbc/anyname");
         conn = ds.getConnection("anyuser", "anypassword");
      }
      catch (Throwable t)
      {
         // DataSource not found. Try to construct a new DataSource.
         // It will be used by all subsequent IDB samples.
         try
         {
            com.ibm.websphere.advanced.cm.factory.DataSourceFactory factory = new com.ibm.websphere.advanced.cm.factory.DataSourceFactory();
            Attributes attrs = new Attributes();
            attrs.name   = "anyname";
            attrs.driver = driver;
            attrs.url    = URL;
            attrs.max = 30;
            ds = factory.createJDBCDataSource(attrs);
            conn = ds.getConnection("anyuser", "anypassword");
            try
            {
               factory.bindDataSource(ds);
            }
            catch (javax.naming.NamingException namingExc)
            {
            }
         }
         catch (Throwable t1)
         {
            t1.printStackTrace();
         }
      }
      return conn;
   }
}
